(() => {
  var __webpack_modules__ = {
    272: (module) => {
      const STRIP_FILENAME_RE = /^[^:]+: /;
      const format = (err) => {
        if (err instanceof SyntaxError) {
          err.name = "SyntaxError";
          err.message = err.message.replace(STRIP_FILENAME_RE, "");
          err.hideStack = true;
        } else if (err instanceof TypeError) {
          err.name = null;
          err.message = err.message.replace(STRIP_FILENAME_RE, "");
          err.hideStack = true;
        }
        return err;
      };
      class LoaderError extends Error {
        constructor(err) {
          super();
          const { name, message, codeFrame, hideStack } = format(err);
          this.name = "BabelLoaderError";
          this.message = `${name ? `${name}: ` : ""}${message}\n\n${codeFrame}\n`;
          this.hideStack = hideStack;
          Error.captureStackTrace(this, this.constructor);
        }
      }
      module.exports = LoaderError;
    },
    124: (module, __unused_webpack_exports, __nccwpck_require__) => {
      const os = __nccwpck_require__(857);
      const path = __nccwpck_require__(928);
      const zlib = __nccwpck_require__(106);
      const { promisify } = __nccwpck_require__(23);
      const { readFile, writeFile, mkdir } = __nccwpck_require__(943);
      const { sync: findUpSync } = __nccwpck_require__(609);
      const { env } = process;
      const transform = __nccwpck_require__(790);
      const serialize = __nccwpck_require__(436);
      let defaultCacheDirectory = null;
      const gunzip = promisify(zlib.gunzip);
      const gzip = promisify(zlib.gzip);
      const read = async function (filename, compress) {
        const data = await readFile(filename + (compress ? ".gz" : ""));
        const content = compress ? await gunzip(data) : data;
        return JSON.parse(content.toString());
      };
      const write = async function (filename, compress, result) {
        const content = JSON.stringify(result);
        const data = compress ? await gzip(content) : content;
        return await writeFile(filename + (compress ? ".gz" : ""), data);
      };
      const filename = function (source, identifier, options, hash) {
        hash.update(serialize([options, source, identifier]));
        return hash.digest("hex") + ".json";
      };
      const addTimestamps = async function (
        externalDependencies,
        getFileTimestamp,
      ) {
        for (const depAndEmptyTimestamp of externalDependencies) {
          try {
            const [dep] = depAndEmptyTimestamp;
            const { timestamp } = await getFileTimestamp(dep);
            depAndEmptyTimestamp.push(timestamp);
          } catch {}
        }
      };
      const areExternalDependenciesModified = async function (
        externalDepsWithTimestamp,
        getFileTimestamp,
      ) {
        for (const depAndTimestamp of externalDepsWithTimestamp) {
          const [dep, timestamp] = depAndTimestamp;
          let newTimestamp;
          try {
            newTimestamp = (await getFileTimestamp(dep)).timestamp;
          } catch {
            return true;
          }
          if (timestamp !== newTimestamp) {
            return true;
          }
        }
        return false;
      };
      const handleCache = async function (directory, params) {
        const {
          source,
          options = {},
          cacheIdentifier,
          cacheDirectory,
          cacheCompression,
          hash,
          getFileTimestamp,
          logger,
        } = params;
        const file = path.join(
          directory,
          filename(source, cacheIdentifier, options, hash),
        );
        try {
          logger.debug(`reading cache file '${file}'`);
          const result = await read(file, cacheCompression);
          if (
            !(await areExternalDependenciesModified(
              result.externalDependencies,
              getFileTimestamp,
            ))
          ) {
            logger.debug(`validated cache file '${file}'`);
            return result;
          }
          logger.debug(
            `discarded cache file '${file}' due to changes in external dependencies`,
          );
        } catch {
          logger.debug(`discarded cache as it can not be read`);
        }
        const fallback =
          typeof cacheDirectory !== "string" && directory !== os.tmpdir();
        try {
          logger.debug(`creating cache folder '${directory}'`);
          await mkdir(directory, { recursive: true });
        } catch (err) {
          if (fallback) {
            return handleCache(os.tmpdir(), params);
          }
          throw err;
        }
        logger.debug(`applying Babel transform`);
        const result = await transform(source, options);
        await addTimestamps(result.externalDependencies, getFileTimestamp);
        try {
          logger.debug(`writing result to cache file '${file}'`);
          await write(file, cacheCompression, result);
        } catch (err) {
          if (fallback) {
            return handleCache(os.tmpdir(), params);
          }
          throw err;
        }
        return result;
      };
      module.exports = async function (params) {
        let directory;
        if (typeof params.cacheDirectory === "string") {
          directory = params.cacheDirectory;
        } else {
          defaultCacheDirectory ??= findCacheDir("babel-loader");
          directory = defaultCacheDirectory;
        }
        return await handleCache(directory, params);
      };
      function findCacheDir(name) {
        if (
          env.CACHE_DIR &&
          !["true", "false", "1", "0"].includes(env.CACHE_DIR)
        ) {
          return path.join(env.CACHE_DIR, name);
        }
        const rootPkgJSONPath = path.dirname(findUpSync("package.json"));
        if (rootPkgJSONPath) {
          return path.join(rootPkgJSONPath, "node_modules", ".cache", name);
        }
        return os.tmpdir();
      }
    },
    674: (module, __unused_webpack_exports, __nccwpck_require__) => {
      let babel;
      try {
        babel = __nccwpck_require__(571);
      } catch (err) {
        if (err.code === "MODULE_NOT_FOUND") {
          err.message +=
            "\n babel-loader@9 requires Babel 7.12+ (the package '@babel/core'). " +
            "If you'd like to use Babel 6.x ('babel-core'), you should install 'babel-loader@7'.";
        }
        throw err;
      }
      if (/^6\./.test(babel.version)) {
        throw new Error(
          "\n babel-loader@9 will not work with the '@babel/core@6' bridge package. " +
            "If you want to use Babel 6.x, install 'babel-loader@7'.",
        );
      }
      const { version } = __nccwpck_require__(344);
      const cache = __nccwpck_require__(124);
      const transform = __nccwpck_require__(790);
      const injectCaller = __nccwpck_require__(846);
      const schema = __nccwpck_require__(348);
      const { isAbsolute } = __nccwpck_require__(928);
      const { promisify } = __nccwpck_require__(23);
      function subscribe(subscriber, metadata, context) {
        if (context[subscriber]) {
          context[subscriber](metadata);
        }
      }
      module.exports = makeLoader();
      module.exports.custom = makeLoader;
      function makeLoader(callback) {
        const overrides = callback ? callback(babel) : undefined;
        return function (source, inputSourceMap) {
          const callback = this.async();
          loader.call(this, source, inputSourceMap, overrides).then(
            (args) => callback(null, ...args),
            (err) => callback(err),
          );
        };
      }
      async function loader(source, inputSourceMap, overrides) {
        const filename = this.resourcePath;
        const logger = this.getLogger("babel-loader");
        let loaderOptions = this.getOptions(schema);
        if (loaderOptions.customize != null) {
          if (!isAbsolute(loaderOptions.customize)) {
            throw new Error(
              "Customized loaders must be passed as absolute paths, since " +
                "babel-loader has no way to know what they would be relative to.",
            );
          }
          if (overrides) {
            throw new Error(
              "babel-loader's 'customize' option is not available when already " +
                "using a customized babel-loader wrapper.",
            );
          }
          logger.debug(
            `loading customize override: '${loaderOptions.customize}'`,
          );
          let override = require(loaderOptions.customize);
          if (override.__esModule) override = override.default;
          if (typeof override !== "function") {
            throw new Error("Custom overrides must be functions.");
          }
          logger.debug("applying customize override to @babel/core");
          overrides = override(babel);
        }
        let customOptions;
        if (overrides && overrides.customOptions) {
          logger.debug("applying overrides customOptions() to loader options");
          const result = await overrides.customOptions.call(
            this,
            loaderOptions,
            { source, map: inputSourceMap },
          );
          customOptions = result.custom;
          loaderOptions = result.loader;
        }
        if ("forceEnv" in loaderOptions) {
          this.emitWarning(
            new Error(
              "The option `forceEnv` has been removed in favor of `envName` in Babel 7.",
            ),
          );
        }
        if (typeof loaderOptions.babelrc === "string") {
          this.emitWarning(
            new Error(
              "The option `babelrc` should not be set to a string anymore in the babel-loader config. " +
                "Please update your configuration and set `babelrc` to true or false.\n" +
                "If you want to specify a specific babel config file to inherit config from " +
                "please use the `extends` option.\nFor more information about this options see " +
                "https://babeljs.io/docs/#options",
            ),
          );
        }
        logger.debug("normalizing loader options");
        if (
          Object.prototype.hasOwnProperty.call(loaderOptions, "sourceMap") &&
          !Object.prototype.hasOwnProperty.call(loaderOptions, "sourceMaps")
        ) {
          loaderOptions = Object.assign({}, loaderOptions, {
            sourceMaps: loaderOptions.sourceMap,
          });
          delete loaderOptions.sourceMap;
        }
        const programmaticOptions = Object.assign({}, loaderOptions, {
          filename,
          inputSourceMap: inputSourceMap || loaderOptions.inputSourceMap,
          sourceMaps:
            loaderOptions.sourceMaps === undefined
              ? this.sourceMap
              : loaderOptions.sourceMaps,
          sourceFileName: filename,
        });
        delete programmaticOptions.customize;
        delete programmaticOptions.cacheDirectory;
        delete programmaticOptions.cacheIdentifier;
        delete programmaticOptions.cacheCompression;
        delete programmaticOptions.metadataSubscribers;
        logger.debug("resolving Babel configs");
        const config = await babel.loadPartialConfigAsync(
          injectCaller(programmaticOptions, this.target),
        );
        if (config) {
          let options = config.options;
          if (overrides && overrides.config) {
            logger.debug("applying overrides config() to Babel config");
            options = await overrides.config.call(this, config, {
              source,
              map: inputSourceMap,
              customOptions,
            });
          }
          if (options.sourceMaps === "inline") {
            options.sourceMaps = true;
          }
          const {
            cacheDirectory = null,
            cacheIdentifier = "core" +
              transform.version +
              "," +
              "loader" +
              version,
            cacheCompression = true,
            metadataSubscribers = [],
          } = loaderOptions;
          let result;
          if (cacheDirectory) {
            logger.debug("cache is enabled");
            const getFileTimestamp = promisify((path, cb) => {
              this._compilation.fileSystemInfo.getFileTimestamp(path, cb);
            });
            const hash = this.utils.createHash(
              this._compilation.outputOptions.hashFunction,
            );
            result = await cache({
              source,
              options,
              transform,
              cacheDirectory,
              cacheIdentifier,
              cacheCompression,
              hash,
              getFileTimestamp,
              logger,
            });
          } else {
            logger.debug("cache is disabled, applying Babel transform");
            result = await transform(source, options);
          }
          config.files.forEach((configFile) => {
            this.addDependency(configFile);
            logger.debug(`added '${configFile}' to webpack dependencies`);
          });
          if (result) {
            if (overrides && overrides.result) {
              logger.debug(
                "applying overrides result() to Babel transform results",
              );
              result = await overrides.result.call(this, result, {
                source,
                map: inputSourceMap,
                customOptions,
                config,
                options,
              });
            }
            const { code, map, metadata, externalDependencies } = result;
            externalDependencies?.forEach(([dep]) => {
              this.addDependency(dep);
              logger.debug(`added '${dep}' to webpack dependencies`);
            });
            metadataSubscribers.forEach((subscriber) => {
              subscribe(subscriber, metadata, this);
              logger.debug(
                `invoked metadata subscriber '${String(subscriber)}'`,
              );
            });
            return [code, map];
          }
        }
        return [source, inputSourceMap];
      }
    },
    846: (module) => {
      module.exports = function injectCaller(opts, target) {
        return Object.assign({}, opts, {
          caller: Object.assign(
            {
              name: "babel-loader",
              target,
              supportsStaticESM: true,
              supportsDynamicImport: true,
              supportsTopLevelAwait: true,
            },
            opts.caller,
          ),
        });
      };
    },
    436: (module) => {
      var objToString = Object.prototype.toString;
      var objKeys = Object.getOwnPropertyNames;
      function serialize(val, isArrayProp) {
        var i, max, str, keys, key, propVal, toStr;
        if (val === true) {
          return "!0";
        }
        if (val === false) {
          return "!1";
        }
        switch (typeof val) {
          case "object":
            if (val === null) {
              return null;
            } else if (val.toJSON && typeof val.toJSON === "function") {
              return serialize(val.toJSON(), isArrayProp);
            } else {
              toStr = objToString.call(val);
              if (toStr === "[object Array]") {
                str = "[";
                max = val.length - 1;
                for (i = 0; i < max; i++) {
                  str += serialize(val[i], true) + ",";
                }
                if (max > -1) {
                  str += serialize(val[i], true);
                }
                return str + "]";
              } else if (toStr === "[object Object]") {
                keys = objKeys(val).sort();
                max = keys.length;
                str = "{";
                i = 0;
                while (i < max) {
                  key = keys[i];
                  propVal = serialize(val[key], false);
                  if (propVal !== undefined) {
                    if (str) {
                      str += ",";
                    }
                    str += '"' + key + '":' + propVal;
                  }
                  i++;
                }
                return str + "}";
              } else {
                return JSON.stringify(val);
              }
            }
          case "function":
          case "undefined":
            return isArrayProp ? null : undefined;
          case "string":
            return val;
          default:
            return isFinite(val) ? val : null;
        }
      }
      module.exports = function (val) {
        var returnVal = serialize(val, false);
        if (returnVal !== undefined) {
          return "" + returnVal;
        }
      };
    },
    790: (module, __unused_webpack_exports, __nccwpck_require__) => {
      const babel = __nccwpck_require__(571);
      const { promisify } = __nccwpck_require__(23);
      const LoaderError = __nccwpck_require__(272);
      const transform = promisify(babel.transform);
      module.exports = async function (source, options) {
        let result;
        try {
          result = await transform(source, options);
        } catch (err) {
          throw err.message && err.codeFrame ? new LoaderError(err) : err;
        }
        if (!result) return null;
        const { ast, code, map, metadata, sourceType, externalDependencies } =
          result;
        if (map && (!map.sourcesContent || !map.sourcesContent.length)) {
          map.sourcesContent = [source];
        }
        return {
          ast,
          code,
          map,
          metadata,
          sourceType,
          externalDependencies: Array.from(
            externalDependencies || [],
            (dep) => [dep],
          ).sort(),
        };
      };
      module.exports.version = babel.version;
    },
    609: (module, __unused_webpack_exports, __nccwpck_require__) => {
      "use strict";
      const path = __nccwpck_require__(928);
      const locatePath = __nccwpck_require__(440);
      const pathExists = __nccwpck_require__(374);
      const stop = Symbol("findUp.stop");
      module.exports = async (name, options = {}) => {
        let directory = path.resolve(options.cwd || "");
        const { root } = path.parse(directory);
        const paths = [].concat(name);
        const runMatcher = async (locateOptions) => {
          if (typeof name !== "function") {
            return locatePath(paths, locateOptions);
          }
          const foundPath = await name(locateOptions.cwd);
          if (typeof foundPath === "string") {
            return locatePath([foundPath], locateOptions);
          }
          return foundPath;
        };
        while (true) {
          const foundPath = await runMatcher({ ...options, cwd: directory });
          if (foundPath === stop) {
            return;
          }
          if (foundPath) {
            return path.resolve(directory, foundPath);
          }
          if (directory === root) {
            return;
          }
          directory = path.dirname(directory);
        }
      };
      module.exports.sync = (name, options = {}) => {
        let directory = path.resolve(options.cwd || "");
        const { root } = path.parse(directory);
        const paths = [].concat(name);
        const runMatcher = (locateOptions) => {
          if (typeof name !== "function") {
            return locatePath.sync(paths, locateOptions);
          }
          const foundPath = name(locateOptions.cwd);
          if (typeof foundPath === "string") {
            return locatePath.sync([foundPath], locateOptions);
          }
          return foundPath;
        };
        while (true) {
          const foundPath = runMatcher({ ...options, cwd: directory });
          if (foundPath === stop) {
            return;
          }
          if (foundPath) {
            return path.resolve(directory, foundPath);
          }
          if (directory === root) {
            return;
          }
          directory = path.dirname(directory);
        }
      };
      module.exports.exists = pathExists;
      module.exports.sync.exists = pathExists.sync;
      module.exports.stop = stop;
    },
    440: (module, __unused_webpack_exports, __nccwpck_require__) => {
      "use strict";
      const path = __nccwpck_require__(928);
      const fs = __nccwpck_require__(896);
      const { promisify } = __nccwpck_require__(23);
      const pLocate = __nccwpck_require__(601);
      const fsStat = promisify(fs.stat);
      const fsLStat = promisify(fs.lstat);
      const typeMappings = { directory: "isDirectory", file: "isFile" };
      function checkType({ type }) {
        if (type in typeMappings) {
          return;
        }
        throw new Error(`Invalid type specified: ${type}`);
      }
      const matchType = (type, stat) =>
        type === undefined || stat[typeMappings[type]]();
      module.exports = async (paths, options) => {
        options = {
          cwd: process.cwd(),
          type: "file",
          allowSymlinks: true,
          ...options,
        };
        checkType(options);
        const statFn = options.allowSymlinks ? fsStat : fsLStat;
        return pLocate(
          paths,
          async (path_) => {
            try {
              const stat = await statFn(path.resolve(options.cwd, path_));
              return matchType(options.type, stat);
            } catch {
              return false;
            }
          },
          options,
        );
      };
      module.exports.sync = (paths, options) => {
        options = {
          cwd: process.cwd(),
          allowSymlinks: true,
          type: "file",
          ...options,
        };
        checkType(options);
        const statFn = options.allowSymlinks ? fs.statSync : fs.lstatSync;
        for (const path_ of paths) {
          try {
            const stat = statFn(path.resolve(options.cwd, path_));
            if (matchType(options.type, stat)) {
              return path_;
            }
          } catch {}
        }
      };
    },
    600: (module, __unused_webpack_exports, __nccwpck_require__) => {
      "use strict";
      const Queue = __nccwpck_require__(179);
      const pLimit = (concurrency) => {
        if (
          !(
            (Number.isInteger(concurrency) || concurrency === Infinity) &&
            concurrency > 0
          )
        ) {
          throw new TypeError(
            "Expected `concurrency` to be a number from 1 and up",
          );
        }
        const queue = new Queue();
        let activeCount = 0;
        const next = () => {
          activeCount--;
          if (queue.size > 0) {
            queue.dequeue()();
          }
        };
        const run = async (fn, resolve, ...args) => {
          activeCount++;
          const result = (async () => fn(...args))();
          resolve(result);
          try {
            await result;
          } catch {}
          next();
        };
        const enqueue = (fn, resolve, ...args) => {
          queue.enqueue(run.bind(null, fn, resolve, ...args));
          (async () => {
            await Promise.resolve();
            if (activeCount < concurrency && queue.size > 0) {
              queue.dequeue()();
            }
          })();
        };
        const generator = (fn, ...args) =>
          new Promise((resolve) => {
            enqueue(fn, resolve, ...args);
          });
        Object.defineProperties(generator, {
          activeCount: { get: () => activeCount },
          pendingCount: { get: () => queue.size },
          clearQueue: {
            value: () => {
              queue.clear();
            },
          },
        });
        return generator;
      };
      module.exports = pLimit;
    },
    601: (module, __unused_webpack_exports, __nccwpck_require__) => {
      "use strict";
      const pLimit = __nccwpck_require__(600);
      class EndError extends Error {
        constructor(value) {
          super();
          this.value = value;
        }
      }
      const testElement = async (element, tester) => tester(await element);
      const finder = async (element) => {
        const values = await Promise.all(element);
        if (values[1] === true) {
          throw new EndError(values[0]);
        }
        return false;
      };
      const pLocate = async (iterable, tester, options) => {
        options = { concurrency: Infinity, preserveOrder: true, ...options };
        const limit = pLimit(options.concurrency);
        const items = [...iterable].map((element) => [
          element,
          limit(testElement, element, tester),
        ]);
        const checkLimit = pLimit(options.preserveOrder ? 1 : Infinity);
        try {
          await Promise.all(
            items.map((element) => checkLimit(finder, element)),
          );
        } catch (error) {
          if (error instanceof EndError) {
            return error.value;
          }
          throw error;
        }
      };
      module.exports = pLocate;
    },
    374: (module, __unused_webpack_exports, __nccwpck_require__) => {
      "use strict";
      const fs = __nccwpck_require__(896);
      const { promisify } = __nccwpck_require__(23);
      const pAccess = promisify(fs.access);
      module.exports = async (path) => {
        try {
          await pAccess(path);
          return true;
        } catch (_) {
          return false;
        }
      };
      module.exports.sync = (path) => {
        try {
          fs.accessSync(path);
          return true;
        } catch (_) {
          return false;
        }
      };
    },
    179: (module) => {
      class Node {
        constructor(value) {
          this.value = value;
          this.next = undefined;
        }
      }
      class Queue {
        constructor() {
          this.clear();
        }
        enqueue(value) {
          const node = new Node(value);
          if (this._head) {
            this._tail.next = node;
            this._tail = node;
          } else {
            this._head = node;
            this._tail = node;
          }
          this._size++;
        }
        dequeue() {
          const current = this._head;
          if (!current) {
            return;
          }
          this._head = this._head.next;
          this._size--;
          return current.value;
        }
        clear() {
          this._head = undefined;
          this._tail = undefined;
          this._size = 0;
        }
        get size() {
          return this._size;
        }
        *[Symbol.iterator]() {
          let current = this._head;
          while (current) {
            yield current.value;
            current = current.next;
          }
        }
      }
      module.exports = Queue;
    },
    344: (module) => {
      "use strict";
      module.exports = require("./package.json");
    },
    571: (module) => {
      "use strict";
      module.exports = require("@babel/core");
    },
    896: (module) => {
      "use strict";
      module.exports = require("fs");
    },
    943: (module) => {
      "use strict";
      module.exports = require("fs/promises");
    },
    857: (module) => {
      "use strict";
      module.exports = require("os");
    },
    928: (module) => {
      "use strict";
      module.exports = require("path");
    },
    23: (module) => {
      "use strict";
      module.exports = require("util");
    },
    106: (module) => {
      "use strict";
      module.exports = require("zlib");
    },
    348: (module) => {
      "use strict";
      module.exports = JSON.parse(
        '{"title":"Babel Loader options","type":"object","properties":{"cacheDirectory":{"anyOf":[{"type":"boolean"},{"type":"string"}],"default":false},"cacheIdentifier":{"type":"string"},"cacheCompression":{"type":"boolean","default":true},"customize":{"anyOf":[{"type":"null"},{"type":"string"}],"default":null},"metadataSubscribers":{"type":"array"}},"additionalProperties":true}',
      );
    },
  };
  var __webpack_module_cache__ = {};
  function __nccwpck_require__(moduleId) {
    var cachedModule = __webpack_module_cache__[moduleId];
    if (cachedModule !== undefined) {
      return cachedModule.exports;
    }
    var module = (__webpack_module_cache__[moduleId] = { exports: {} });
    var threw = true;
    try {
      __webpack_modules__[moduleId](
        module,
        module.exports,
        __nccwpck_require__,
      );
      threw = false;
    } finally {
      if (threw) delete __webpack_module_cache__[moduleId];
    }
    return module.exports;
  }
  if (typeof __nccwpck_require__ !== "undefined")
    __nccwpck_require__.ab = __dirname + "/";
  var __webpack_exports__ = __nccwpck_require__(674);
  module.exports = __webpack_exports__;
})();
